@@ -1,4 +1,4 @@
-from funcnodes import Shelf
+from funcnodes_core import Shelf
 from .logic import NODE_SHELF as logic_shelf
 from .math_nodes import NODE_SHELF as math_shelf
 from .lists import NODE_SHELF as lists_shelf
@@ -6,7 +6,7 @@ from .strings import NODE_SHELF as strings_shelf
 from .dicts import NODE_SHELF as dicts_shelf
 
 
-__version__ = "0.1.5"
+__version__ = "0.1.6"
 
 NODE_SHELF = Shelf(
     nodes=[],
